@@ -59,7 +59,7 @@ def convert(topology, backend, device, extra_config={}):
 
             if backend == onnx.__name__:
                 # vers = LooseVersion(torch.__version__)
-                # allowed_min = LooseVersion("1.6.1")
+                # allowed_min = LooseVersion("1.6.0")
                 # Pytorch <= 1.6.0 has a bug with exporting GEMM into ONNX.
                 # For the moment only tree_trav is enabled for pytorch <= 1.6.0
                 # if vers < allowed_min:
@@ -93,10 +93,17 @@ def convert(topology, backend, device, extra_config={}):
         if output_model_name is None:
             output_model_name = str(uuid4().hex) + ".onnx"
 
+        # Put the tracing test input into the right format.
+        trace_input = extra_config[constants.TEST_INPUT]
+        if type(trace_input) is tuple:
+            trace_input = tuple([torch.from_numpy(i) for i in trace_input])
+        else:
+            trace_input = torch.from_numpy(trace_input)
+
         # Generate the ONNX models
         torch.onnx.export(
             torch_model,
-            torch.from_numpy(extra_config[constants.TEST_INPUT]),
+            trace_input,
             output_model_name,
             input_names=topology.raw_model.input_names,
             output_names=topology.raw_model.output_names,
@@ -110,6 +117,44 @@ def convert(topology, backend, device, extra_config={}):
         # Set the ONNX model name if any.
         if onnx_model_name is not None:
             hb_model.graph.name = onnx_model_name
+
+        # Fix the model to use arbitrary batch dimensions
+        def fix_dim(dim):
+            updated = False
+            if dim.HasField("dim_value"):
+                dim.Clear()
+                updated = True
+                dim.dim_param = "sym"
+
+            return updated
+
+        def fix_value_info(value):
+            num_fixed = 0
+            if value.type.HasField("tensor_type"):
+                shape = value.type.tensor_type.shape
+                if shape:
+                    dim = shape.dim[0]
+                    if fix_dim(dim):
+                        num_fixed += 1
+
+            return num_fixed
+
+        def fix_graph(graph):
+            num_fixed = 0
+            for input in graph.input:
+                num_fixed += fix_value_info(input)
+
+            for output in graph.output:
+                num_fixed += fix_value_info(output)
+
+            for node in graph.node:
+                for attr in node.attribute:
+                    if attr.HasField("g"):
+                        num_fixed += fix_graph(attr.g)
+
+            return num_fixed
+
+        fix_graph(hb_model.graph)
     else:
         # Set the device for the model.
         if device != "cpu":
@@ -122,6 +167,7 @@ def convert(topology, backend, device, extra_config={}):
             if device != "cpu":
                 test_data.to(device)
             torch_model = torch.jit.trace(torch_model, test_data).eval()
+            torch.jit.optimized_execution(torch_model)
         hb_model = torch_model
 
     # Return if the container is not needed.
