@@ -41,11 +41,17 @@ ONNX_INPUTS = "onnx_inputs"
 TEST_INPUT = "test_input"
 """The test input data for models that need to be traced"""
 
+N_INPUTS = "n_inputs"
+"""Number of inputs expected by the model."""
+
 NUM_TREES = "n_trees"
 """Number of trees composing an ensemble"""
 
 OFFSET = "offset"
 """offset of the sklearn anomaly detection implementation"""
 
+IFOREST_THRESHOLD = "iforest_threshold"
+"""threshold of the sklearn isolation forest implementation, backward compatibility for sklearn <= 0.21"""
+
 MAX_SAMPLES = "max_samples"
 """max_samples of sklearn isolation forest implementation"""
