@@ -13,31 +13,46 @@ TorchScript,
 ONNX
 
 **Supported Operators**
+BernoulliNB,
+Binarizer,
 DecisionTreeClassifier,
 DecisionTreeRegressor,
 ExtraTreesClassifier,
 ExtraTreesRegressor,
+FastICA,
+GaussianNB,
 GradientBoostingClassifier,
 GradientBoostingRegressor,
 HistGradientBoostingClassifier,
 HistGradientBoostingRegressor,
 IsolationForest,
+KernelPCA,
+KBinsDiscretizer,
 LinearRegression,
 LinearSVC,
 LogisticRegression,
 LogisticRegressionCV,
 MaxAbsScaler,
 MinMaxScaler,
+MissingIndicator,
+MLPClassifier,
+MLPRegressor,
+MultinomialNB,
 Normalizer,
 OneHotEncoder,
+PCA,
+PolynomialFeatures,
 RandomForestClassifier,
 RandomForestRegressor,
 RobustScaler,
 SelectKBest,
+SelectPercentile,
+SimpleImputer,
 SGDClassifier,
 StandardScaler,
 TreeEnsembleClassifier,
 TreeEnsembleRegressor,
+TruncatedSVD,
 VarianceThreshold,
 
 LGBMClassifier,
@@ -50,8 +65,8 @@ XGBRanker,
 XGBRegressor
 """
 from collections import defaultdict
-from .exceptions import MissingConverter
 
+from .exceptions import MissingConverter
 from ._utils import torch_installed, sklearn_installed, lightgbm_installed, xgboost_installed, onnx_runtime_installed
 
 
@@ -89,13 +104,41 @@ def _build_sklearn_operator_list():
         # SVM-based models
         from sklearn.svm import LinearSVC, SVC, NuSVC
 
+        # Imputers
+        from sklearn.impute import MissingIndicator, SimpleImputer
+
+        # MLP Models
+        from sklearn.neural_network import MLPClassifier, MLPRegressor
+
+        # Naive Bayes Models
+        from sklearn.naive_bayes import BernoulliNB, GaussianNB, MultinomialNB
+
+        # Matrix decomposition transformers
+        from sklearn.decomposition import PCA, KernelPCA, FastICA, TruncatedSVD
+
         # Preprocessing
-        from sklearn.preprocessing import MaxAbsScaler, MinMaxScaler, Normalizer, OneHotEncoder, RobustScaler, StandardScaler
+        from sklearn.preprocessing import (
+            Binarizer,
+            KBinsDiscretizer,
+            MaxAbsScaler,
+            MinMaxScaler,
+            Normalizer,
+            OneHotEncoder,
+            PolynomialFeatures,
+            RobustScaler,
+            StandardScaler,
+        )
+
+        try:
+            from sklearn.preprocessing import Imputer
+        except ImportError:
+            # Imputer was deprecate in sklearn >= 0.22
+            Imputer = None
 
         # Features
-        from sklearn.feature_selection import SelectKBest, VarianceThreshold
+        from sklearn.feature_selection import SelectKBest, SelectPercentile, VarianceThreshold
 
-        return [
+        supported_ops = [
             # Trees
             DecisionTreeClassifier,
             DecisionTreeRegressor,
@@ -115,20 +158,42 @@ def _build_sklearn_operator_list():
             LogisticRegression,
             LogisticRegressionCV,
             SGDClassifier,
+            # Other models
+            BernoulliNB,
+            GaussianNB,
+            MLPClassifier,
+            MLPRegressor,
+            MultinomialNB,
             # SVM
             NuSVC,
             SVC,
+            # Imputers
+            Imputer,
+            MissingIndicator,
+            SimpleImputer,
             # Preprocessing
+            Binarizer,
+            KBinsDiscretizer,
             MaxAbsScaler,
             MinMaxScaler,
             Normalizer,
+            PolynomialFeatures,
             RobustScaler,
             StandardScaler,
+            # Matrix Decomposition
+            FastICA,
+            KernelPCA,
+            PCA,
+            TruncatedSVD,
             # Feature selection
             SelectKBest,
+            SelectPercentile,
             VarianceThreshold,
         ]
 
+        # Remove all deprecated operators given the sklearn version. E.g., Imputer for sklearn > 0.21.3.
+        return [x for x in supported_ops if x is not None]
+
     return []
 
 
@@ -210,7 +275,17 @@ def _build_sklearn_api_operator_name_map():
     Associate Sklearn with the operator class names.
     If two scikit-learn (API) models share a single name, it means they are equivalent in terms of conversion.
     """
-    return {k: "Sklearn" + k.__name__ for k in sklearn_operator_list + xgb_operator_list + lgbm_operator_list}
+    # Pipeline ops. These are ops injected by the parser not "real" sklearn operators.
+    pipeline_operator_list = [
+        "ArrayFeatureExtractor",
+        "Concat",
+        "Multiply",
+    ]
+
+    return {
+        k: "Sklearn" + k.__name__ if hasattr(k, "__name__") else k
+        for k in sklearn_operator_list + pipeline_operator_list + xgb_operator_list + lgbm_operator_list
+    }
 
 
 def _build_onnxml_api_operator_name_map():
@@ -282,5 +357,11 @@ ONNX_INITIAL_TYPES = "onnx_initial_types"
 ONNX_TARGET_OPSET = "onnx_target_opset"
 """For ONNX models we can set the target opset to use. 9 by default."""
 
+INPUT_NAMES = "input_names"
+"""Set the names of the inputs. Assume that the numbers onf inputs_names is equal to the number of inputs."""
+
+OUTPUT_NAMES = "output_names"
+"""Set the names of the outputs."""
+
 CONTAINER = "container"
 """Whether to return the container for Sklearn API or just the model"""
